@@ -146,8 +146,9 @@ def info(ctx: Ctx, file_path: Path) -> None:
     """Outputs information about a SV file."""
     file = parse_file(file_path)
     for module in file.modules:
-        table = gen_markdown_table(module)
-        ctx.console.print(table)
+        table_io, table_param = gen_markdown_table(module)
+        ctx.console.print(table_param)
+        ctx.console.print(table_io)
 
 
 @cli.command()
